summaryrefslogtreecommitdiffstats
path: root/remoting/host/desktop_environment.h
diff options
context:
space:
mode:
authoralexeypa@chromium.org <alexeypa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-09 03:04:56 +0000
committeralexeypa@chromium.org <alexeypa@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-03-09 03:04:56 +0000
commit61cfdc559d4939f1ced7fdb173597d0d2c382d19 (patch)
treede1ffaf56503a6d80857cf2df72c0793586af844 /remoting/host/desktop_environment.h
parentd3a5a0b2f0cc1fc01ee544d1b382334a36a845d3 (diff)
downloadchromium_src-61cfdc559d4939f1ced7fdb173597d0d2c382d19.zip
chromium_src-61cfdc559d4939f1ced7fdb173597d0d2c382d19.tar.gz
chromium_src-61cfdc559d4939f1ced7fdb173597d0d2c382d19.tar.bz2
ResizingHostObserver is created by the desktop environment together with other stubs.
ResizingHostObserver is responsible to resizing the host desktop so that it matches the client resolution. This CL makes the desktop environment responsible for creation of ResizingHostObserver object along with other stubs. Related changes: - Added a new interface: SessionController. Objects implementing it will be responsible for handling control events. The client resolution change is the only supported event at the moment. - Removed OnClientResolutionChanged() from the host status observer. - The multi-process host does not handle OnClientResolutionChanged() notifications at the moment. BUG=137696 Review URL: https://chromiumcodereview.appspot.com/12545026 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@187130 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting/host/desktop_environment.h')
-rw-r--r--remoting/host/desktop_environment.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/remoting/host/desktop_environment.h b/remoting/host/desktop_environment.h
index f91fb85..6a6a82c 100644
--- a/remoting/host/desktop_environment.h
+++ b/remoting/host/desktop_environment.h
@@ -24,6 +24,7 @@ namespace remoting {
class AudioCapturer;
class EventExecutor;
+class SessionController;
// Provides factory methods for creation of audio/video capturers and event
// executor for a given desktop environment.
@@ -31,13 +32,14 @@ class DesktopEnvironment {
public:
virtual ~DesktopEnvironment() {}
// Factory methods used to create audio/video capturers and event executor for
// a particular desktop environment.
virtual scoped_ptr<AudioCapturer> CreateAudioCapturer(
scoped_refptr<base::SingleThreadTaskRunner> audio_task_runner) = 0;
virtual scoped_ptr<EventExecutor> CreateEventExecutor(
scoped_refptr<base::SingleThreadTaskRunner> input_task_runner,
scoped_refptr<base::SingleThreadTaskRunner> ui_task_runner) = 0;
+ virtual scoped_ptr<SessionController> CreateSessionController() = 0;
virtual scoped_ptr<media::ScreenCapturer> CreateVideoCapturer(
scoped_refptr<base::SingleThreadTaskRunner> capture_task_runner,
scoped_refptr<base::SingleThreadTaskRunner> encode_task_runner) = 0;
@@ -31,13 +32,14 @@ class DesktopEnvironment {
public:
virtual ~DesktopEnvironment() {}
- // Factory methods used to create audio/video capturers and event executor for
- // a particular desktop environment.
+ // Factory methods used to create audio/video capturers, event executor, and
+ // session controller for a particular desktop environment.
virtual scoped_ptr<AudioCapturer> CreateAudioCapturer(
scoped_refptr<base::SingleThreadTaskRunner> audio_task_runner) = 0;